@@ -7,4 +7,7 @@ from .PgsFile import write_to_txt
 from .PgsFile import write_to_excel
 from .PgsFile import write_to_json
 
+from .PgsFile import FilePath
+from .PgsFile import FileName
+
 name = "PgsFile"
\ No newline at end of file
